@@ -7,3 +7,6 @@ Mozilla Public License, version 2.0; see LICENSE.
 """
 
 debug_mode = 0 # 0 - no debug info; 1 - debug info
+binmode = 0 # 1- equal volume; anything else - increasing volume
+
+__version__ = '1.1.3.post7'
