@@ -7,13 +7,15 @@ Mozilla Public License, version 2.0; see LICENSE.
 """
 
 from __future__ import absolute_import, division, print_function, unicode_literals
-
-from emda import iotools
 import fcodes_fast
+from emda.core import iotools, maptools, restools
 
 def main():
     iotools.test()
+    maptools.test()
+    restools.test()
     fcodes_fast.test()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
